==> openbazaar-0.0.2.tar.gz: openbazaar-0.0.2/admin/users_login.php <==
<?php
/* *********************************************************
  $Id: users_login.php,v 1.1.2.6 2003/11/07 12:11:48 shota Exp $
  ⥸塼̾: users_log.php
 * 2002-05-13
 * Naomi Suzukawa
 * suzukawa@bitscope.co.jp
  ----------------------------------------------------------
桼

  ѹ
********************************************************* */

  define('TABLE_CONFIGURATION', 'configuration');
  define('TABLE_LANGUAGES', 'languages');
  define('FILENAME_DEFAULT', 'index.php');

// Set the local configuration parameters - mainly for developers
  if (file_exists(DIR_FS_INCLUDES . 'local/configure.php')) include(DIR_FS_INCLUDES . 'local/configure.php');

// Include application configuration parameters
  require('../lib/admin/configure.php');

// initialize the logger class
  require(DIR_FS_CLASSES . 'logger.php');

// 2003-01-30 add -s
  session_name('osCAdminsID');
// 2003-01-30 add -e

  // åID 
  // PHPSESSIDΥå̾ǵϿƤ
  setcookie(session_name(), '', time() - 3600, '/');
  setcookie(session_name(), '', time() - 3600, substr(DIR_WS_ADMIN, 0, -1));

// include the database functions
  require(DIR_FS_FUNCTIONS . 'database.php');

// make a connection to the database... now
  tep_db_connect() or die('Unable to connect to database server!');

// set application wide parameters
  $configuration_query = tep_db_query('select configuration_key as cfgKey, configuration_value as cfgValue from ' . TABLE_CONFIGURATION . '');
  while ($configuration = tep_db_fetch_array($configuration_query)) {
    define($configuration['cfgkey'], $configuration['cfgvalue']);
  }

// language
  require(DIR_FS_FUNCTIONS . 'languages.php');
  $_SESSION["language"] = tep_get_languages_directory(DEFAULT_LANGUAGE);

// include the language translations
  require(DIR_FS_LANGUAGES . $_SESSION["language"] . '.php');

// define our general functions used application-wide
  require(DIR_FS_FUNCTIONS . 'general.php');
  require(DIR_FS_FUNCTIONS . 'html_output.php');

if (file_exists(DIR_FS_LANGUAGES . $_SESSION["language"] . '/user_certify.php')) {
	include(DIR_FS_LANGUAGES . $_SESSION["language"] . '/user_certify.php');
}
/* -------------------------------------
	ɽ
 ------------------------------------ */

// 顼å
$msg = ($_GET['erf'] ? '<div align="center"><font color="#FF0000">'.TEXT_ERRINFO_LOGIN.'</font></div>' : '');

echo '<!doctype html public "-//W3C//DTD HTML 4.01 Transitional//EN">' . "\n";
echo '<html ' . HTML_PARAMS . '>' . "\n";
echo '<head>' . "\n";
echo '<meta http-equiv="Content-Type" content="text/html; charset=' . CHARSET . '">' . "\n";
echo '<title>' . TITLE . '</title>' . "\n";
echo '<link rel="stylesheet" type="text/css" href="stylesheet.css">' . "\n";
echo '</head>' . "\n";
echo '<body marginwidth="0" marginheight="0" topmargin="0" bottommargin="0" leftmargin="0" rightmargin="0" bgcolor="#FFFFFF">' . "\n";

echo tep_draw_form('defaultpage', FILENAME_DEFAULT . "?SID=" . session_id());		// <form>ν

echo '<!-- body_text //-->' . "\n";
echo '<table border="0" cellspacing="0" cellpadding="2">' . "\n";
echo '<tr>' . "\n";
echo '<td>';
echo tep_image(DIR_WS_IMAGES . 'oscommerce.gif', 'osCommerce', '204', '50');
echo '</td>' . "\n";
echo '</tr>' . "\n";

echo '<tr>' . "\n";
echo '<td align="center">';

echo '<table border="0" cellspacing="0" cellpadding="2">' . "\n";
echo '<tr>' . "\n";
echo '<td class="pageHeading" colspan="2">' . HEADING_TITLE_ . '<br><br></td>' . "\n";
echo '</tr>' . "\n";

echo '<tr>';
echo '<td>' . TABLE_HEADING_USER . "</td>\n";
echo '<td>';
echo tep_draw_input_field("loginuid", '', 'size="10"', FALSE, 'text', FALSE);
echo '</td>' . "\n";
echo '</tr>' . "\n";

echo '<tr>';
echo '<td>' . TABLE_HEADING_PASSWORD . "</td>\n";
echo '<td>';
echo tep_draw_input_field("loginpwd", '', 'size="10"', FALSE, 'password', false);
echo '</td>' . "\n";
echo '</tr>' . "\n";

echo '<tr>';
echo '<td>&nbsp;</td>' . "\n";
echo '<td align="center">';
echo tep_draw_input_field("execute_login", BUTTON_LOGIN, "", FALSE, "submit", FALSE);	// 
echo '</td>' . "\n";
echo '</tr>' . "\n";
echo '</table>' . "\n";

echo $msg;

echo '</td>' . "\n";
echo '</tr>' . "\n";
echo '</table>' . "\n";

echo "</form>\n";						// եΥեå

echo "</body>\n";
echo "</html>\n";
?>

==> openbazaar-0.0.3.tar.gz: openbazaar-0.0.3/admin/users_login.php <==
<?php
/* *********************************************************
  $Id: users_login.php,v 1.2 2004/01/08 09:40:45 shota Exp $
  ⥸塼̾: users_log.php
 * 2002-05-13
 * Naomi Suzukawa
 * suzukawa@bitscope.co.jp
  ----------------------------------------------------------
桼

  ѹ
********************************************************* */

  define('TABLE_CONFIGURATION', 'configuration');
  define('TABLE_LANGUAGES', 'languages');
  define('FILENAME_DEFAULT', 'index.php');

// Set the local configuration parameters - mainly for developers
  if (file_exists(DIR_FS_INCLUDES . 'local/configure.php')) include(DIR_FS_INCLUDES . 'local/configure.php');

// Include application configuration parameters
  require('../lib/admin/configure.php');

// initialize the logger class
  require(DIR_FS_CLASSES . 'logger.php');

// 2003-01-30 add -s
  session_name('osCAdminsID');
// 2003-01-30 add -e

  // åID 
  // PHPSESSIDΥå̾ǵϿƤ
  setcookie(session_name(), '', time() - 3600, '/');
  setcookie(session_name(), '', time() - 3600, substr(DIR_WS_ADMIN, 0, -1));

// include the database functions
  require(DIR_FS_FUNCTIONS . 'database.php');

// make a connection to the database... now
  tep_db_connect() or die('Unable to connect to database server!');

// set application wide parameters
  $configuration_query = tep_db_query('select configuration_key as cfgKey, configuration_value as cfgValue from ' . TABLE_CONFIGURATION . '');
  while ($configuration = tep_db_fetch_array($configuration_query)) {
    define($configuration['cfgkey'], $configuration['cfgvalue']);
  }

// language
  require(DIR_FS_FUNCTIONS . 'languages.php');
  $_SESSION["language"] = tep_get_languages_directory(DEFAULT_LANGUAGE);

// include the language translations
  require(DIR_FS_LANGUAGES . $_SESSION["language"] . '.php');

// define our general functions used application-wide
  require(DIR_FS_FUNCTIONS . 'general.php');
  require(DIR_FS_FUNCTIONS . 'html_output.php');

if (file_exists(DIR_FS_LANGUAGES . $_SESSION["language"] . '/user_certify.php')) {
	include(DIR_FS_LANGUAGES . $_SESSION["language"] . '/user_certify.php');
}
/* -------------------------------------
	ɽ
 ------------------------------------ */

// 顼å
$msg = ($_GET['erf'] ? '<div align="center"><font color="#FF0000">'.TEXT_ERRINFO_LOGIN.'</font></div>' : '');

echo '<!doctype html public "-//W3C//DTD HTML 4.01 Transitional//EN">' . "\n";
echo '<html ' . HTML_PARAMS . '>' . "\n";
echo '<head>' . "\n";
echo '<meta http-equiv="Content-Type" content="text/html; charset=' . CHARSET . '">' . "\n";
echo '<title>' . TITLE . '</title>' . "\n";
echo '<link rel="stylesheet" type="text/css" href="stylesheet.css">' . "\n";
echo '</head>' . "\n";
echo '<body marginwidth="0" marginheight="0" topmargin="0" bottommargin="0" leftmargin="0" rightmargin="0" bgcolor="#FFFFFF">' . "\n";

//echo tep_draw_form('defaultpage', FILENAME_DEFAULT . "?SID=" . session_id());		// <form>ν
echo tep_draw_form('defaultpage', FILENAME_DEFAULT);		// <form>ν

echo '<!-- body_text //-->' . "\n";
echo '<table border="0" cellspacing="0" cellpadding="2">' . "\n";
echo '<tr>' . "\n";
echo '<td>';
echo tep_image(DIR_WS_IMAGES . 'oscommerce.gif', 'osCommerce', '204', '50');
echo '</td>' . "\n";
echo '</tr>' . "\n";

echo '<tr>' . "\n";
echo '<td align="center">';

echo '<table border="0" cellspacing="0" cellpadding="2">' . "\n";
echo '<tr>' . "\n";
echo '<td class="pageHeading" colspan="2">' . HEADING_TITLE_ . '<br><br></td>' . "\n";
echo '</tr>' . "\n";

echo '<tr>';
echo '<td>' . TABLE_HEADING_USER . "</td>\n";
echo '<td>';
echo tep_draw_input_field("loginuid", '', 'size="10"', FALSE, 'text', FALSE);
echo '</td>' . "\n";
echo '</tr>' . "\n";

echo '<tr>';
echo '<td>' . TABLE_HEADING_PASSWORD . "</td>\n";
echo '<td>';
echo tep_draw_input_field("loginpwd", '', 'size="10"', FALSE, 'password', false);
echo '</td>' . "\n";
echo '</tr>' . "\n";

echo '<tr>';
echo '<td>&nbsp;</td>' . "\n";
echo '<td align="center">';
echo tep_draw_input_field("execute_login", BUTTON_LOGIN, "", FALSE, "submit", FALSE);	// 
echo '</td>' . "\n";
echo '</tr>' . "\n";
echo '</table>' . "\n";

echo $msg;

echo '</td>' . "\n";
echo '</tr>' . "\n";
echo '</table>' . "\n";

echo "</form>\n";						// եΥեå

echo "</body>\n";
echo "</html>\n";
?>
